Learn R Programming

riskRegression (version 2021.10.10)

IC_Nelson_Aalen_cens_time: Influence function for Nelson-Aalen estimator.

Description

Fast computation of influence function for Nelson-Aalen estimator of the censoring times

Usage

IC_Nelson_Aalen_cens_time(time, status)

Arguments

time

sorted vector of event times. Sorted according to time and -status so that events come first a tied times.

status

sorted vector of 0 = censored or 1 = event (any cause). Sorted according to time and -status so that events come first a tied times.

Value

A square matrix where each column corresponds to a subject and each row to a time point.

Examples

Run this code
# NOT RUN {
time = c(1,3,3,4)
status = c(1,0,1,1)
IC_Nelson_Aalen_cens_time(time,status)
# }

Run the code above in your browser using DataLab