Learn R Programming

riskRegression (version 1.1.7)

Melanoma: Malignant melanoma data

Description

In the period 1962-77, 205 patients with malignant melanoma (cancer of the skin) had a radical operation performed at Odense University Hospital, Denmark. All patients were followed until the end of 1977 by which time 134 were still alive while 71 had died (of out whom 57 had died from cancer and 14 from other causes).

Arguments

Format

A data frame with 205 observations on the following 12 variables.
time
time in days from operation
status
a numeric with values 0=censored 1=death.malignant.melanoma 2=death.other.causes
event
a factor with levels censored death.malignant.melanoma death.other.causes
invasion
a factor with levels level.0, level.1, level.2
ici
inflammatory cell infiltration (ICI): 0, 1, 2 or 3
epicel
a factor with levels not present present
ulcer
a factor with levels not present present
thick
tumour thickness (in 1/100 mm)
sex
a factor with levels Female Male
age
age at operation (years)
logthick
tumour thickness on log-scale

Details

The object of the study was to assess the effect of risk factors on survival. Among such risk factors were the sex and age of the patients and the histological variables tumor thickness and ulceration (absent vs. present).

References

Regression with linear predictors (2010)

Andersen, P.K. and Skovgaard, L.T.

Springer Verlag

Examples

Run this code
data(Melanoma)

Run the code above in your browser using DataLab