coxBaseEstimator: Extract the type of estimator for the baseline hazard

View source: R/coxBaseEstimator.R

coxBaseEstimatorR Documentation

Extract the type of estimator for the baseline hazard

Description

Extract the type of estimator for the baseline hazard

Usage

coxBaseEstimator(object)

## S3 method for class 'coxph'
coxBaseEstimator(object)

## S3 method for class 'phreg'
coxBaseEstimator(object)

## S3 method for class 'prodlim'
coxBaseEstimator(object)

## S3 method for class 'GLMnet'
coxBaseEstimator(object)

Arguments

object

The fitted Cox regression model object either obtained with coxph (survival package), cph (rms package), or phreg (mets package).

Author(s)

Brice Ozenne broz@sund.ku.dk


riskRegression documentation built on Feb. 16, 2026, 5:06 p.m.