coxStrataLevel: Returns the name of the strata in Cox model

View source: R/coxStrataLevel.R

coxStrataLevelR Documentation

Returns the name of the strata in Cox model

Description

Return the name of the strata in Cox model

Usage

coxStrataLevel(object)

## S3 method for class 'coxph'
coxStrataLevel(object)

## S3 method for class 'cph'
coxStrataLevel(object)

## S3 method for class 'phreg'
coxStrataLevel(object)

## S3 method for class 'prodlim'
coxStrataLevel(object)

Arguments

object

The fitted Cox regression model object either obtained with coxph (survival package), cph (rms package), or phreg (mets package).

Author(s)

Brice Ozenne broz@sund.ku.dk


riskRegression documentation built on Feb. 16, 2026, 5:06 p.m.