Compute the decomposition in iid elements of the ML estimor of IPCW logistic regressions.
# S3 method for wglm
iid(x, times = NULL, simplify = TRUE, store = NULL, ...)a wglm object.
[numeric vector] time points at which the iid should be output.
[logical] should the ouput be converted to a matrix when only one timepoint is requested. Otherwise will always return a list.
[vector] when evaluating the iid, should prediction be only computed for unique covariate sets and mapped back to the original dataset (data="minimal"). Otherwise use data="full".
Not used.