Learn R Programming

riskRegression (version 2020.02.05)

plot.riskRegression: Plotting predicted risk

Description

Show predicted risk obtained by a risk prediction model as a function of time.

Usage

# S3 method for riskRegression
plot(x,
  cause,
  newdata,
  xlab,
  ylab,
  xlim,
  ylim,
  lwd,
  col,
  lty,
  axes=TRUE,
  percent=TRUE,
  legend=TRUE,
  add=FALSE,
  ...)

Arguments

x

Fitted object obtained with one of ARR, LRR, riskRegression.

cause

For CauseSpecificCox models the cause of interest.

newdata

A data frame containing predictor variable combinations for which to compute predicted risk.

xlab

See plot

ylab

See plot

xlim

See plot

ylim

See plot

lwd

A vector of line thicknesses for the regression coefficients.

col

A vector of colors for the regression coefficients.

lty

A vector of line types for the regression coefficients.

axes

Logical. If FALSE then do not draw axes.

percent

If true the y-axis is labeled in percent.

legend

If true draw a legend.

add

Logical. If TRUE then add lines to an existing plot.

…

Used for transclusion of smart arguments for plot, lines, axis and background. See function SmartControl from prodlim.

Examples

Run this code
# NOT RUN {
library(survival)
library(prodlim)
data(Melanoma)
fit.arr <- ARR(Hist(time,status)~invasion+age+strata(sex),data=Melanoma,cause=1)
plot(fit.arr,xlim=c(500,3000))


# }

Run the code above in your browser using DataLab