Learn R Programming

riskRegression (version 2019.11.03)

summary.ate: Summary Average Treatment Effects

Description

Summary average treatment effects.

Usage

# S3 method for ate
summary(object, digits = 3, type = c("meanRisk",
  "diffRisk", "ratioRisk"), estimator = object$estimator[1], ...)

Arguments

object

object obtained with function ate

digits

[integer, >0] Number of digits.

type

[character vector] what to displayed. Can be any combination of "meanRisk", "diffRisk", and "ratioRisk".

estimator

[character] The type of estimator relative to which the estimates should be displayed.

...

passed to print

Details

to display confidence intervals/bands and p.value, the confint method needs to be applied on the object.

See Also

confint.ate to compute confidence intervals/bands. ate to compute the average treatment effects.