Summary average treatment effects.
# S3 method for ate
summary(object, digits = 3, type = c("meanRisk",
"diffRisk", "ratioRisk"), estimator = object$estimator[1], ...)object obtained with function ate
[integer, >0] Number of digits.
[character vector] what to displayed.
Can be any combination of "meanRisk", "diffRisk", and "ratioRisk".
[character] The type of estimator relative to which the estimates should be displayed.
passed to print
to display confidence intervals/bands and p.value,
the confint method needs to be applied on the object.
confint.ate to compute confidence intervals/bands.
ate to compute the average treatment effects.